This package is package for solve assembly line balancing problem. It can solve single model assembly line and 3 types of assembly line:

    - Straight-Line Assembly Line
    - U-shaped Assembly Line
    - Parallel Workstation Assembly Line

It have 5 function in this package:

| Function name | Description                    |
| ------------- | ------------------------------ |
| `lcr(filename)`       | Use largest candidate rule to solve the straight-line assembly line balancing problem.        |
| `rpw(filename)`   | Use rank position weight to solve the straight-line assembly line balancing problem.     |
| `comsoal(filename)` | Use comsoal to solve the straight-line assembly line balancing problem. |
| `u_ga(filename)` | Use genetic algorithm to solve the u-shaped assembly line balancing problem. |
| `parallel_ga(filename)` | Use genetic algorithm to solve the parallel workstation assembly line balancing problem |



